@@ -20,6 +20,8 @@ pub fn compile(lexer: &Lexer) -> Result<Vec<u8>, CompilationError> {
                 res.push(MOV_R);
             } else if token.clone_value() == "qhalt" {
                 res.push(QHALT);
+            } else if token.clone_value() == "prt_d" {
+                res.push(PRT_D);
             } else {
                 return Err(CompilationError::with_string(format!("unknown identifier '{}'", token.clone_value())));
             }
